@@ -17,11 +17,18 @@ use FindBin                 qw( $Bin            );
 use List::Util              qw( first           );
 use Symbol                  qw( qualify_to_ref  );
 
+use Module::FromPerlVer::Util
+qw
+(
+    search_cwd
+);
+
 ########################################################################
 # package variables & sanity checks
 ########################################################################
 
 our $VERSION    = version->parse( 'v0.1.1' )->numify;
+my $verbose     = $ENV{ VERBOSE_FROMPERLVER };
 
 my $nil         = sub{};
 
@@ -38,50 +45,33 @@ my @restore     = qw( git checkout  --theirs                    );
 # utility subs
 ########################################################################
 
-my $locate_tarball
+my $search_for
 = sub
 {
-    # note that $Bin may be ./t, in which case the
-    # extract may to move up a level.
-
-    my $extract = shift;
-    my $base    = shift;
-    my $root    = $Bin;
-
-    print "# Locate tarball: '$base' ($root).";
-
-    for(;;)
-    {
-        '/' eq $root
-        and return;
-
-        print "#\t$root";
-
-        -e and return $_
-        for "$root/$base";
-
-        $root       = dirname $root;
-    }
-
-    return
+    &search_cwd 
+    or
+    &search_bin
 };
 
 my @handlerz = 
 (
     # simplest case first, to more complicated.
+    # silently ignore anything that isn't found along the way.
 
     sub
     {
-        -e './.git'
+        $search_for->( '.git' )
     },
 
     sub
     {
+        # lacking the tarball is fatal if the tarball is supplied.
+
         my $extract = shift;
         my $tball   = $extract->value( 'git_tarball' )
         or return;
 
-        my $path    = $extract->$locate_tarball( $tball )
+        my $path    = $search_for->( $tball )
         or die "Missing: '$tball' ($Bin)";
 
         print "# Extract repo from: '$path'";
@@ -113,12 +103,11 @@ my @handlerz =
         print STDERR "\n# Cloning from: '$url'\n";
 
         my $output  = qx{ $cmd };
-
-        if( my $status  = $? )
+        if( my $err  = $? )
         {
             die <<END
 
-    Non-zero:   '$status'.
+    Non-zero:   '$err'.
     Executing:  '$cmd'.
     Cloning:    '$url'."
     Output:
@@ -161,10 +150,7 @@ sub source_prefix
 
 sub module_sources
 {
-$DB::single = 1;
-
     my $extract = shift;
-    my $dir     = getcwd;
 
     # whichever one returns indicates that there is a 
     # working .git directory.
@@ -182,8 +168,6 @@ $DB::single = 1;
     my $prefix  = $extract->value( 'git_prefix' )
     or
     die "Botched module_sources: no 'git_prefix' available.\n";
-    
-    # force a list context for qx to get tags as array.
 
     chomp
     (
@@ -192,7 +176,8 @@ $DB::single = 1;
     or
     die "No tags like '$prefix*' found.\n";
 
-    print join "\n#\t" => "# Git tags: '$prefix*'", @tagz;
+    print join "\n#\t" => "#  Git tags: '$prefix*'", @tagz
+    if $verbose;
 
     # at this point git should be able to checkout the
     # tag contents so get_files should work.
@@ -209,8 +194,6 @@ sub source_files
 
 sub get_files
 {
-$DB::single = 1;
-
     my $extract = shift;
     my $tag     = $extract->value( 'module_source' );
 
@@ -222,20 +205,25 @@ $DB::single = 1;
 
     $extract->value( restore_branch => $curr );
 
-    # no telling what the tag might look like.
-    # quotes protect it from the shell.
+    my $cmd
+    = do
+    {
+        # no telling what the tag might look like.
+        # quotes protect it from the shell.
 
-    my $cmd     = join ' ' => @checkout, $tag;
+        local $"    = ' ';
+        
+        "@checkout '$tag'"
+    };
 
-    my @status = qx{ $cmd };
-
-    if( $? )
+    my @output = qx{ $cmd };
+    if( my $err = $? )
     {
         local $, = "\n#\t";
 
-        chomp @status;
+        chomp @output;
 
-        print 'Checkout result:', @status;
+        print STDERR join "\n\t" => "Non-zero: $err ($cmd)", @output;
 
         die "Non-zero exit: $? from '$cmd'.\n";
     }
